@@ -30,12 +30,12 @@ import decimal
 import compas._os
 
 
-__author__    = 'Tom Van Mele and many others (see AUTHORS.md)'
+__author__ = 'Tom Van Mele and many others (see AUTHORS.md)'
 __copyright__ = 'Copyright 2014-2019 - Block Research Group, ETH Zurich'
-__license__   = 'MIT License'
-__email__     = 'vanmelet@ethz.ch'
+__license__ = 'MIT License'
+__email__ = 'vanmelet@ethz.ch'
 
-__version__ = '0.10.0'
+__version__ = '0.11.0'
 
 
 PY3 = sys.version_info[0] == 3
@@ -50,6 +50,26 @@ APPTEMP = compas._os.absjoin(APPDATA, 'temp')
 
 PRECISION = '3f'
 
+# Check if COMPAS is installed from git
+# If that's the case, try to append the current head's hash to __version__
+try:
+    git_head_file = compas._os.absjoin(HOME, '.git', 'HEAD')
+
+    if os.path.exists(git_head_file):
+        # git head file contains one line that looks like this:
+        # ref: refs/heads/master
+        with open(git_head_file, 'r') as git_head:
+            _, ref_path = git_head.read().strip().split(' ')
+            ref_path = ref_path.split('/')
+
+            git_head_refs_file = compas._os.absjoin(HOME, '.git', *ref_path)
+
+        if os.path.exists(git_head_refs_file):
+            with open(git_head_refs_file, 'r') as git_head_ref:
+                git_commit = git_head_ref.read().strip()
+                __version__ += '-' + git_commit[:8]
+except Exception:
+    pass
 
 __all__ = [
     'raise_if_windows',
@@ -69,6 +89,8 @@ def is_windows():
 
     """
     return os.name == 'nt'
+
+
 WINDOWS = is_windows()
 
 
@@ -82,6 +104,8 @@ def is_linux():
 
     """
     return os.name == 'posix'
+
+
 LINUX = is_linux()
 
 
@@ -95,6 +119,8 @@ def is_mono():
 
     """
     return 'mono' in sys.version.lower()
+
+
 MONO = is_mono()
 
 
@@ -108,6 +134,8 @@ def is_ironpython():
 
     """
     return 'ironpython' in sys.version.lower()
+
+
 IPY = is_ironpython()
 
 
