@@ -1,6 +1,6 @@
 """
 ********************************************************************************
-compas.com
+com
 ********************************************************************************
 
 .. currentmodule:: compas.com
@@ -35,7 +35,7 @@ ssh
     :nosignatures:
 
     SSH
-    Euler
+    EulerSSH
 
 """
 from __future__ import absolute_import
