@@ -49,7 +49,7 @@ class KDTree(object):
 
         from compas.geometry import KDTree
         from compas.geometry import pointcloud_xy
-        from compas.plotters import Plotter
+        from compas_plotters import Plotter
 
         plotter = Plotter()
 
@@ -223,7 +223,7 @@ class KDTree(object):
 if __name__ == '__main__':
 
     from compas.geometry import pointcloud_xy
-    from compas.plotters import Plotter
+    from compas_plotters import Plotter
 
     plotter = Plotter()
 
