@@ -2,10 +2,13 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
+import compas
 
-from .fd_alglib import *
-from .fd_cpp import *
-from .fd_numpy import *
+# from .fd_alglib import *
+# from .fd_cpp import *
+
+if not compas.IPY:
+    from .fd_numpy import *
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
