@@ -2,10 +2,8 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
-import os
 import time
 import json
-import sys
 
 import compas
 
@@ -17,7 +15,6 @@ except ImportError:
 try:
     from subprocess import Popen
     from subprocess import PIPE
-    from subprocess import STDOUT
 
 except ImportError:
     try:
@@ -28,7 +25,6 @@ except ImportError:
 import compas._os
 
 from compas.utilities import DataEncoder
-from compas.utilities import DataDecoder
 
 from compas.rpc import RPCServerError
 
@@ -90,41 +86,7 @@ class Proxy(object):
 
     .. code-block:: python
 
-        import compas
-        import time
-
-        from compas.datastructures import Mesh
-        from compas.rpc import Proxy
-
-        numerical = Proxy('compas.numerical')
-
-        mesh = Mesh.from_obj(compas.get('faces.obj'))
-
-        mesh.update_default_vertex_attributes({'px': 0.0, 'py': 0.0, 'pz': 0.0})
-        mesh.update_default_edge_attributes({'q': 1.0})
-
-        key_index = mesh.key_index()
-
-        xyz   = mesh.get_vertices_attributes('xyz')
-        edges = [(key_index[u], key_index[v]) for u, v in mesh.edges()]
-        fixed = [key_index[key] for key in mesh.vertices_where({'vertex_degree': 2})]
-        q     = mesh.get_edges_attribute('q', 1.0)
-        loads = mesh.get_vertices_attributes(('px', 'py', 'pz'), (0.0, 0.0, 0.0))
-
-        xyz, q, f, l, r = numerical.fd_numpy(xyz, edges, fixed, q, loads)
-
-        for key, attr in mesh.vertices(True):
-            index = key
-            attr['x'] = xyz[index][0]
-            attr['y'] = xyz[index][1]
-            attr['z'] = xyz[index][2]
-            attr['rx'] = r[index][0]
-            attr['ry'] = r[index][1]
-            attr['rz'] = r[index][2]
-
-        for index, (u, v, attr) in enumerate(mesh.edges(True)):
-            attr['f'] = f[index][0]
-            attr['l'] = l[index][0]
+        pass
 
     """
 
@@ -141,15 +103,22 @@ class Proxy(object):
         self.service = service
         self.package = package
 
+        self._implicitely_started_server = False
         self._server = self.try_reconnect()
         if self._server is None:
             self._server = self.start_server()
+            self._implicitely_started_server = True
 
     def __enter__(self):
         return self
 
     def __exit__(self, *args):
-        self.stop_server()
+        # If we started the RPC server, we will try to clean up and stop it
+        # otherwise we just disconnect from it
+        if self._implicitely_started_server:
+            self.stop_server()
+        else:
+            self._server.__close()
 
     @property
     def address(self):
@@ -204,7 +173,7 @@ class Proxy(object):
         server = ServerProxy(self.address)
         try:
             server.ping()
-        except:
+        except Exception:
             return None
         else:
             print("Reconnecting to an existing server proxy.")
@@ -227,6 +196,11 @@ class Proxy(object):
         """
         env = compas._os.prepare_environment()
 
+        # this part starts the server side of the RPC setup
+        # it basically launches a subprocess
+        # to start the default service
+        # the default service creates a server
+        # and registers a dispatcher for custom functionality
         try:
             Popen
         except NameError:
@@ -248,6 +222,9 @@ class Proxy(object):
             args = [self.python, '-m', self.service, str(self._port)]
             self._process = Popen(args, stdout=PIPE, stderr=PIPE, env=env)
 
+        # this starts the client side
+        # it creates a proxy for the server
+        # and tries to connect the proxy to the actual server
         server = ServerProxy(self.address)
 
         print("Starting a new proxy server...")
@@ -257,7 +234,7 @@ class Proxy(object):
         while count:
             try:
                 server.ping()
-            except:
+            except Exception:
                 time.sleep(0.1)
                 count -= 1
                 print("    {} attempts left.".format(count))
@@ -277,7 +254,7 @@ class Proxy(object):
         print("Stopping the server proxy.")
         try:
             self._server.remote_shutdown()
-        except:
+        except Exception:
             pass
         self._terminate_process()
 
@@ -292,11 +269,11 @@ class Proxy(object):
 
         try:
             self._process.terminate()
-        except:
+        except Exception:
             pass
         try:
             self._process.kill()
-        except:
+        except Exception:
             pass
 
     def __getattr__(self, name):
@@ -304,7 +281,7 @@ class Proxy(object):
             name = "{}.{}".format(self.package, name)
         try:
             self._function = getattr(self._server, name)
-        except:
+        except Exception:
             raise RPCServerError()
         return self.proxy
 
@@ -333,9 +310,15 @@ class Proxy(object):
         idict = {'args': args, 'kwargs': kwargs}
         istring = json.dumps(idict, cls=DataEncoder)
 
+        # it makes sense that there is a broken pipe error
+        # because the process is not the one receiving the feedback
+        # when there is a print statement on the server side
+        # this counts as output
+        # it should be sent as part of RPC communication
         try:
             ostring = self._function(istring)
-        except:
+        except Exception:
+            # not clear what the point of this is
             self.stop_server()
             raise
 
@@ -358,46 +341,6 @@ class Proxy(object):
 
 if __name__ == "__main__":
 
-    import compas
-    import sys
+    import doctest
 
-    from compas.datastructures import Mesh
-    from compas.rpc import Proxy
-
-    from compas_rhino.artists import MeshArtist
-
-    numerical = Proxy('compas.numerical')
-
-    mesh = Mesh.from_obj(compas.get('faces.obj'))
-
-    mesh.update_default_vertex_attributes({'px': 0.0, 'py': 0.0, 'pz': 0.0})
-    mesh.update_default_edge_attributes({'q': 1.0})
-
-    key_index = mesh.key_index()
-
-    xyz   = mesh.get_vertices_attributes('xyz')
-    edges = [(key_index[u], key_index[v]) for u, v in mesh.edges()]
-    fixed = [key_index[key] for key in mesh.vertices_where({'vertex_degree': 2})]
-    q     = mesh.get_edges_attribute('q', 1.0)
-    loads = mesh.get_vertices_attributes(('px', 'py', 'pz'), (0.0, 0.0, 0.0))
-
-    xyz, q, f, l, r = numerical.fd_numpy(xyz, edges, fixed, q, loads)
-
-    for key, attr in mesh.vertices(True):
-        index = key
-        attr['x'] = xyz[index][0]
-        attr['y'] = xyz[index][1]
-        attr['z'] = xyz[index][2]
-        attr['rx'] = r[index][0]
-        attr['ry'] = r[index][1]
-        attr['rz'] = r[index][2]
-
-    for index, (u, v, attr) in enumerate(mesh.edges(True)):
-        attr['f'] = f[index][0]
-        attr['l'] = l[index][0]
-
-    artist = MeshArtist(mesh)
-    artist.draw_vertices()
-    artist.draw_edges()
-    artist.draw_faces()
-    artist.redraw()
+    doctest.testmod(globs=globals())
