@@ -27,8 +27,13 @@ import os
 import compas._os
 from .utilities import *
 
+try:
+    import rhinoscriptsyntax as rs
+except ImportError:
+    pass
 
-__version__ = '0.10.0'
+
+__version__ = '0.11.0'
 
 
 PURGE_ON_DELETE = True
@@ -96,7 +101,7 @@ def _get_python_plugins_path(version):
     if compas._os.system == 'win32':
         python_plugins_path = _get_python_plugins_path_win32(version)
     elif compas._os.system == 'darwin':
-        python_plugins_path = _get_python_plugins_path_mac()
+        python_plugins_path = _get_python_plugins_path_mac(version)
     else:
         raise Exception('Unsupported platform')
 
